EdgeKind

Enum EdgeKind 

pub enum EdgeKind {
    Reference,
    Inherits,
}
An edge between two types in the type graph.

Variants



Reference

The source type contains or references the target type.



Inherits

The source type inherits from the target type.