pub struct CookedGraph<'a> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a> CookedGraph<'a>
impl<'a> CookedGraph<'a>
Sourcepub fn schemas(
&self,
) -> impl Iterator<Item = SchemaTypeView<'_, 'a>> + use<'_, 'a>
pub fn schemas( &self, ) -> impl Iterator<Item = SchemaTypeView<'_, 'a>> + use<'_, 'a>
Returns an iterator over all the named schemas in this graph.
Sourcepub fn schema(&self, name: &str) -> Option<SchemaTypeView<'_, 'a>>
pub fn schema(&self, name: &str) -> Option<SchemaTypeView<'_, 'a>>
Looks up and returns a schema by name.
Sourcepub fn primitives(
&self,
) -> impl Iterator<Item = PrimitiveView<'_, 'a>> + use<'_, 'a>
pub fn primitives( &self, ) -> impl Iterator<Item = PrimitiveView<'_, 'a>> + use<'_, 'a>
Returns an iterator over all primitive type nodes in this graph.
Sourcepub fn operations(
&self,
) -> impl Iterator<Item = OperationView<'_, 'a>> + use<'_, 'a>
pub fn operations( &self, ) -> impl Iterator<Item = OperationView<'_, 'a>> + use<'_, 'a>
Returns an iterator over all the operations in this graph.