ViewExtensions

Struct ViewExtensions 

pub struct ViewExtensions<X>(/* private fields */);
Extended data attached to a graph type.

Implementations

Source

impl<'a, X: Extendable<'a>> ViewExtensions<X>

pub fn get<'b, T: Send + Sync + 'static>(&'b self) -> Option<AtomicRef<'b, T>>
where 'a: 'b,

Returns a reference to a value of an arbitrary type that was previously inserted into this extended data.

pub fn insert<T: Send + Sync + 'static>(&mut self, value: T) -> Option<T>

Inserts a value of an arbitrary type into this extended data, and returns the previous value for that type.