pub fn parse<'a>(
arena: &'a Arena,
input: &'a str,
) -> Result<Vec<PathSegment<'a>>, BadPath>Expand description
Parses a path template, like /v1/pets/{petId}/toy.
The grammar for path templating is adapted directly from the OpenAPI spec.
pub fn parse<'a>(
arena: &'a Arena,
input: &'a str,
) -> Result<Vec<PathSegment<'a>>, BadPath>Parses a path template, like /v1/pets/{petId}/toy.
The grammar for path templating is adapted directly from the OpenAPI spec.