pub struct UniqueNames<'a> { /* private fields */ }Expand description
A scope that claims target language names before final case rendering.
UniqueNames canonicalizes source name parts into word segments,
assigns collision suffixes for already-claimed names, and returns
opaque UniqueName handles for codegen to render in any case style.
Implementations
Sourceimpl<'a> UniqueNames<'a>
impl<'a> UniqueNames<'a>
Sourcepub fn with_reserved<'part, R>(arena: &'a Arena, reserved: R) -> Self
pub fn with_reserved<'part, R>(arena: &'a Arena, reserved: R) -> Self
Creates a name scope that reserves existing names.
Sourcepub fn claim<'part>(
&mut self,
parts: impl IntoIterator<Item = NamePart<'part>>,
) -> UniqueName<'a>
pub fn claim<'part>( &mut self, parts: impl IntoIterator<Item = NamePart<'part>>, ) -> UniqueName<'a>
Claims a segmented source name, and returns a name that’s unique within this scope.
If the name has already been claimed, the returned name receives the next free unique numeric suffix.
Sourcepub fn adopt(&mut self, name: UniqueName<'a>) -> UniqueName<'a>
pub fn adopt(&mut self, name: UniqueName<'a>) -> UniqueName<'a>
Claims a name that’s already unique in another scope, and returns a unique form of that name in this scope.