pub struct UniqueNames<'a> { /* private fields */ }Expand description
Deduplicates names across case conventions.
Implementations
Sourceimpl<'a> UniqueNames<'a>
impl<'a> UniqueNames<'a>
pub fn new(arena: &'a Arena) -> Self
pub fn with_reserved<S: AsRef<str>>( arena: &'a Arena, reserved: impl IntoIterator<Item = S>, ) -> Self
Sourcepub fn uniquify(&mut self, name: &str) -> &'a str
pub fn uniquify(&mut self, name: &str) -> &'a str
Adds a name to this scope and returns a unique form.
Names without word content use numeric forms starting at 1.
Examples
let arena = Arena::new();
let mut names = UniqueNames::new(&arena);
assert_eq!(names.uniquify("HTTPResponse"), "HTTPResponse");
assert_eq!(names.uniquify("HTTP_Response"), "HTTP_Response2");
assert_eq!(names.uniquify("httpResponse"), "httpResponse3");
assert_eq!(names.uniquify("http_response_2"), "http_response4");Trait Implementations