pub struct RawGraph<'a> { /* private fields */ }Expand description
A mutable intermediate dependency graph of all the types in a Spec,
backed by a sparse StableDiGraph.
This graph is constructed directly from a Spec, and represents
type relationships as they exist in the spec. Transformations like
inline_tagged_variants rewrite this graph
in place.
After applying all transformations, call cook to
turn this graph into a CookedGraph that’s ready for code generation.
Implementations
Sourceimpl<'a> RawGraph<'a>
impl<'a> RawGraph<'a>
pub fn new(arena: &'a Arena, spec: &'a Spec<'a>) -> Self
Sourcepub fn inline_tagged_variants(&mut self) -> &mut Self
pub fn inline_tagged_variants(&mut self) -> &mut Self
Inlines schema types used as variants of multiple tagged unions with different tags.
In OpenAPI’s model of tagged unions, the tag always references a field that’s defined on each struct variant. This model works well for Python and TypeScript, but not Rust; Serde doesn’t allow struct variants to declare fields with the same name as the tag. The Rust generator excludes tag fields when generating structs, but this introduces a new problem: a struct can’t appear a variant of multiple unions with different tags 1.
This transformation finds and inlines these structs, so that the Rust generator can safely omit their tag fields.
If struct A has fields
fooandbar, A is a variant of tagged unions C and D, C’s tag isfoo, and D’s tag isbar… onlyfooshould be excluded when A is used in C, and onlybarshould be excluded when A is used in D; but this can’t be modeled in Serde without splitting A into two distinct types. ↩
Sourcepub fn cook(&self) -> CookedGraph<'a>
pub fn cook(&self) -> CookedGraph<'a>
Builds an immutable CookedGraph from this mutable raw graph.