pub struct FieldView<'view, 'a, P> { /* private fields */ }Expand description
A graph-aware view of a struct or union field.
Implementations
Sourceimpl<'view, 'graph, 'a: 'graph, P: ViewNode<'graph, 'a>> FieldView<'view, 'a, P>
impl<'view, 'graph, 'a: 'graph, P: ViewNode<'graph, 'a>> FieldView<'view, 'a, P>
Sourcepub fn name(&self) -> StructFieldName<'a>
pub fn name(&self) -> StructFieldName<'a>
Returns the field name.
Sourcepub fn ty(&self) -> TypeView<'graph, 'a>
pub fn ty(&self) -> TypeView<'graph, 'a>
Returns a view of the inner type that this type wraps.
Sourcepub fn description(&self) -> Option<&'a str>
pub fn description(&self) -> Option<&'a str>
Returns the description, if present in the schema.
Sourceimpl<'view, 'graph, 'a> FieldView<'view, 'a, StructView<'graph, 'a>>
impl<'view, 'graph, 'a> FieldView<'view, 'a, StructView<'graph, 'a>>
Sourcepub fn inherited(&self) -> bool
pub fn inherited(&self) -> bool
Returns true if this field was inherited from a parent via allOf.